@@ -2,13 +2,8 @@ from pandas import DataFrame,json_normalize,concat,ExcelWriter
 from os import mkdir
 from os.path import exists,abspath,join
 from subprocess import Popen,PIPE,STDOUT
-from cast_common.logger import Logger
-from pandas.api.types import is_numeric_dtype
 import sys
 
-__author__ = "Nevin Kaplan"
-__email__ = "n.kaplan@castsoftware.com"
-__copyright__ = "Copyright 2022, CAST Software"
 
 def get_between(txt,tag_start,tag_end,start_at=0):
     text = txt[start_at:]
@@ -76,6 +71,40 @@ def each_risk_factor(ppt, aip_data, app_id, app_no):
     ppt.remove_empty_placeholders()
     return risk_grades
 
+def format_table(writer, data, sheet_name,width=None):
+    
+    data.to_excel(writer, index=False, sheet_name=sheet_name, startrow=1,header=False)
+
+    workbook = writer.book
+    worksheet = writer.sheets[sheet_name]
+    rows = len(data)
+    cols = len(data.columns)-1
+    columns=[]
+    for col_num, value in enumerate(data.columns.values):
+        columns.append({'header': value})
+
+    table_options={
+                'columns':columns,
+                'header_row':True,
+                'autofilter':True,
+                'banded_rows':True
+                }
+    worksheet.add_table(0, 0, rows, cols,table_options)
+    
+    header_format = workbook.add_format({'text_wrap':True,
+                                        'align': 'center'})
+
+    col_width = 10
+    if width == None:
+        width = []
+        for i in range(1,len(data.columns)+1):
+           width.append(col_width)
+    for col_num, value in enumerate(data.columns.values):
+        worksheet.write(0, col_num, value, header_format)
+        w=width[col_num]
+        worksheet.set_column(col_num, col_num, w)
+    return worksheet
+
 def find_nth(string, substring, n):
    if (n == 1):
        return string.find(substring)
@@ -144,49 +173,42 @@ def check_process(process:Popen,output=True):
         if output == True and len(line.strip(' ')) > 0:
             print(line)
         ret.append(line)
-    try:
-        stdout, stderr = process.communicate()
-    except: 
-        return process.returncode,ret
+    stdout, stderr = process.communicate()
     return process.returncode,ret
-     
+    
+
 def format_table(writer, data, sheet_name,width=None):
     
-    data.to_excel(writer, index=False, sheet_name=sheet_name, startrow=1,header=False)
+    data.to_excel(writer, index=False, sheet_name=sheet_name, startrow=1,header=False,float_format = "%0.2f")
 
     workbook = writer.book
     worksheet = writer.sheets[sheet_name]
-    rows = len(data)+1
+    rows = len(data)
     cols = len(data.columns)-1
-
     columns=[]
-    first=True
     for col_num, value in enumerate(data.columns.values):
-        json = {'header': value}
-        if first:
-            first=False
-            json['total_string']='Totals'
-        else: 
-            if is_numeric_dtype(data[value]) and data[value].dtype != 'bool':
-                json['total_function']='sum'
-
-        columns.append(json)
+        columns.append({'header': value})
 
     table_options={
-                'total_row':True,
                 'columns':columns,
                 'header_row':True,
                 'autofilter':True,
                 'banded_rows':True
                 }
     worksheet.add_table(0, 0, rows, cols,table_options)
+    
+    header_format = workbook.add_format({'text_wrap':True,
+                                        'align': 'center'})
 
     col_width = 10
     if width == None:
         width = []
         for i in range(1,len(data.columns)+1):
            width.append(col_width)
-
+    for col_num, value in enumerate(data.columns.values):
+        worksheet.write(0, col_num, value, header_format)
+        w=width[col_num]
+        worksheet.set_column(col_num, col_num, w)
     return worksheet
 
 def convert_LOC(total:int):
